@@ -56,13 +56,12 @@ def save_params(params, target_path: Path = None):
 
 
 # ---------- Función común de render (3D+2D) ----------
-# ---------- Función común de render (3D opcional + 2D si fig no es None) ----------
-def render_dump_to(plotter: QtInteractor, fig, dump_path: str):
-    """Dibuja celda + puntos; si fig es None, NO dibuja la vista 2D."""
+def render_dump_to(plotter: QtInteractor, fig: plt.Figure, dump_path: str):
+    """Dibuja celda + puntos igual que load_dump, coloreando por 'Cluster' si existe."""
     pipeline = import_file(dump_path)
     data = pipeline.compute()
 
-    # === Celda desde OVITO ===
+    # === Celda desde OVITO: columnas a1,a2,a3 y última columna origen ===
     M = np.asarray(data.cell.matrix, dtype=float)   # (3x4)
     a1, a2, a3, origin = M[:, 0], M[:, 1], M[:, 2], M[:, 3]
 
@@ -82,7 +81,7 @@ def render_dump_to(plotter: QtInteractor, fig, dump_path: str):
     pos_prop = data.particles.positions
     positions = pos_prop.array if hasattr(pos_prop, "array") else np.asarray(pos_prop, dtype=float)
 
-    # --- Detectar columna de clúster ---
+    # --- Detectar columna de clúster (varios alias posibles) ---
     cluster_vals = None
     for name in ("Cluster", "cluster", "c_Cluster", "c_cluster", "ClusterID", "cluster_id"):
         if name in data.particles:
@@ -91,6 +90,7 @@ def render_dump_to(plotter: QtInteractor, fig, dump_path: str):
             cluster_vals = np.asarray(arr).astype(int).reshape(-1)
             break
 
+    # --- Remapeo a 0..K-1 para paleta discreta ---
     cluster_idx = None
     unique_clusters = None
     if cluster_vals is not None and cluster_vals.shape[0] == positions.shape[0]:
@@ -125,29 +125,27 @@ def render_dump_to(plotter: QtInteractor, fig, dump_path: str):
     plotter.reset_camera()
     plotter.set_scale(1, 1, 1)
 
-    # === Vista 2D (solo si hay fig) ===
-    if fig is not None:
-        fig.clf()
-        ax = fig.add_subplot(111)
-        for i, j in edges:
-            x0, y0 = corners[i][0], corners[i][1]
-            x1, y1 = corners[j][0], corners[j][1]
-            ax.plot([x0, x1], [y0, y1], '-', linewidth=1)
+    # === Vista 2D ===
+    fig.clf()
+    ax = fig.add_subplot(111)
+    for i, j in edges:
+        x0, y0 = corners[i][0], corners[i][1]
+        x1, y1 = corners[j][0], corners[j][1]
+        ax.plot([x0, x1], [y0, y1], '-', linewidth=1)
 
-        if cluster_idx is not None:
-            ax.scatter(
-                positions[:, 0], positions[:, 1], s=10,
-                c=cluster_idx, cmap="tab20",
-                vmin=0, vmax=len(unique_clusters)-1
-            )
-        else:
-            ax.scatter(positions[:, 0], positions[:, 1], s=10, color="k")
-
-        ax.set_xlabel('X'); ax.set_ylabel('Y')
-        ax.set_aspect('equal', 'box')
-        ax.grid(True, linewidth=0.3)
-        fig.canvas.draw()
+    if cluster_idx is not None:
+        ax.scatter(
+            positions[:, 0], positions[:, 1], s=10,
+            c=cluster_idx, cmap="tab20",
+            vmin=0, vmax=len(unique_clusters)-1
+        )
+    else:
+        ax.scatter(positions[:, 0], positions[:, 1], s=10, color="k")
 
+    ax.set_xlabel('X'); ax.set_ylabel('Y')
+    ax.set_aspect('equal', 'box')
+    ax.grid(True, linewidth=0.3)
+    fig.canvas.draw()
 
 
 # ---------- Widgets de viewers internos ----------
@@ -202,42 +200,12 @@ class DumpViewerWidget(QWidget):
         self.path_edit.setText(p)
         render_dump_to(self.plotter, self.fig, p)
 
-
 class KeyAreaSeqWidget(QWidget):
-    """Viewer para outputs/dump/key_area_{i}.dump + panel de distribución (results.csv)."""
-    def __init__(self, parent=None, pattern: str = "outputs/dump/key_area_{i}.dump"):
+    """Panel de métricas (results.csv) SIN selector key_file_{i}."""
+    def __init__(self, parent=None):
         super().__init__(parent)
-        self.pattern = pattern
         self._results_df = None  # cache df results
 
-        # --- Barra superior de navegación por key_area_i.dump ---
-        top = QWidget()
-        top_l = QHBoxLayout(top)
-        self.idx = QSpinBox()
-        self.idx.setRange(0, 1_000_000)
-        self.btn_prev = QPushButton("◀ Prev")
-        self.btn_next = QPushButton("Next ▶")
-        self.btn_load = QPushButton("Load")
-        self.path_lbl = QLineEdit()
-        self.path_lbl.setReadOnly(True)
-
-        top_l.addWidget(QLabel("key_area_{i}.dump   i="))
-        top_l.addWidget(self.idx)
-        top_l.addWidget(self.btn_prev)
-        top_l.addWidget(self.btn_next)
-        top_l.addWidget(self.btn_load)
-        top_l.addWidget(QLabel("Archivo:"))
-        top_l.addWidget(self.path_lbl, 1)
-
-        # --- Centro: viewer dump (3D + 2D) ---
-        viewer = QWidget()
-        viewer_l = QVBoxLayout(viewer)
-        self.plotter = QtInteractor(viewer)
-        viewer_l.addWidget(self.plotter)
-        self.fig = plt.figure(figsize=(4, 4))
-        self.canvas = FigureCanvas(self.fig)
-        viewer_l.addWidget(self.canvas)
-
         # --- Panel de distribución de poros (results.csv) ---
         dist_panel = QWidget()
         dist_l = QVBoxLayout(dist_panel)
@@ -263,50 +231,14 @@ class KeyAreaSeqWidget(QWidget):
         self.canvas_dist = FigureCanvas(self.fig_dist)
         dist_l.addWidget(self.canvas_dist)
 
-        # Conectar señales
-        self.btn_prev.clicked.connect(lambda: self._step(-1))
-        self.btn_next.clicked.connect(lambda: self._step(+1))
-        self.btn_load.clicked.connect(self._load_idx)
+        # Conexión
         self.results_btn.clicked.connect(self.load_results_csv)
 
-        # --- Layout raíz de la pestaña ---
+        # --- Layout raíz de la pestaña (solo el panel de métricas) ---
         root_l = QVBoxLayout(self)
-        root_l.addWidget(top)
-        root_l.addWidget(viewer, 1)
         root_l.addWidget(dist_panel)
 
-        # Intentar autodescubrir primer key_area existente
-        self._auto_seed_index()
-
-    # ----------- helpers key_area viewer -----------
-    def _pattern_path(self, i: int) -> str:
-        return self.pattern.format(i=i)
-
-    def _auto_seed_index(self):
-        for i in range(0, 10000):
-            if Path(self._pattern_path(i)).exists():
-                self.idx.setValue(i)
-                self._load_idx()
-                return
-        self.path_lbl.setText("(no encontrado)")
-
-    def _step(self, delta: int):
-        new_i = max(0, self.idx.value() + delta)
-        self.idx.setValue(new_i)
-        self._load_idx()
-
-    def _load_idx(self):
-        p = self._pattern_path(self.idx.value())
-        self.path_lbl.setText(p)
-        if not Path(p).exists():
-            QMessageBox.warning(self, "No existe", f"No se encontró:\n{p}")
-            return
-        try:
-            render_dump_to(self.plotter, self.fig, p)
-        except Exception as e:
-            QMessageBox.critical(self, "Error", str(e))
-
-    # ----------- panel results.csv -----------
+    # ----------- normalizador de columnas -----------
     def _normalize_results_df(self, df: pd.DataFrame) -> pd.DataFrame:
         # normaliza nombres
         normmap = {c.lower().strip(): c for c in df.columns}
@@ -343,6 +275,7 @@ class KeyAreaSeqWidget(QWidget):
         out = out.dropna(subset=["surface_area", "filled_volume", "predicted_vacancy"])
         return out
 
+    # ----------- carga y ploteo -----------
     def load_results_csv(self):
         try:
             path = Path(self.results_path.text().strip())
@@ -403,13 +336,12 @@ class KeyAreaSeqWidget(QWidget):
         except Exception as e:
             QMessageBox.critical(self, "Error al cargar results.csv", str(e))
 
-
 # ---------- Ventana principal ----------
 class SettingsWindow(QMainWindow):
     def __init__(self):
         super().__init__()
         self.showMaximized()
-        self.setWindowTitle("VacancyFinder-SiMAF   0.3.9.4")
+        self.setWindowTitle("VacancyFinder-SiMAF   0.4.1.4")
 
         self.params = load_params()
         cfg = self.params.setdefault('CONFIG', [{}])[0]
@@ -526,10 +458,14 @@ class SettingsWindow(QMainWindow):
         # --- Tab Viewer 1 ---
         self.viewer1 = DumpViewerWidget()
         tabs.addTab(self.viewer1, "Viewer 1")
-
         # --- Tab Key Areas (ahora con distribución) ---
         self.viewer2 = KeyAreaSeqWidget()
-        tabs.addTab(self.viewer2, "Key Areas")
+        tabs.addTab(self.viewer2, "Metrics")
+        # --- Tab Key Areas (original) ---
+
+        # --- Tab Key Areas (solo 3D/2D, sin CSV ni histogramas) ---
+        self.viewer3d = KeyArea3DOnlyWidget()
+        tabs.addTab(self.viewer3d, "Key Areas")
 
         # Layout principal
         main = QWidget(); hl = QHBoxLayout(main); hl.addWidget(scroll); hl.addWidget(tabs, 1)
@@ -714,6 +650,83 @@ class SettingsWindow(QMainWindow):
             self.log_output.setPlainText(buf.getvalue())
             QMessageBox.critical(self, "Error en análisis", "Falló VacancyAnalysis. Revisa el log.")
 
+class KeyArea3DOnlyWidget(QWidget):
+    """Viewer igual a Key Areas pero SIN tabla ni histogramas (solo navegación + 3D/2D)."""
+    def __init__(self, parent=None, pattern: str = "outputs/dump/key_area_{i}.dump"):
+        super().__init__(parent)
+        self.pattern = pattern
+
+        # --- Barra superior de navegación por key_area_i.dump ---
+        top = QWidget()
+        top_l = QHBoxLayout(top)
+        self.idx = QSpinBox()
+        self.idx.setRange(0, 1_000_000)
+        self.btn_prev = QPushButton("◀ Prev")
+        self.btn_next = QPushButton("Next ▶")
+        self.btn_load = QPushButton("Load")
+        self.path_lbl = QLineEdit()
+        self.path_lbl.setReadOnly(True)
+
+        top_l.addWidget(QLabel("key file"))
+        top_l.addWidget(self.idx)
+        top_l.addWidget(self.btn_prev)
+        top_l.addWidget(self.btn_next)
+        top_l.addWidget(self.btn_load)
+        top_l.addWidget(QLabel("Archivo:"))
+        top_l.addWidget(self.path_lbl, 1)
+
+        # --- Centro: SOLO viewer de dump (3D + 2D interno) ---
+        viewer = QWidget()
+        viewer_l = QVBoxLayout(viewer)
+        self.plotter = QtInteractor(viewer)
+        self.plotter.setMinimumHeight(600)  # para que se vea grande
+        viewer_l.addWidget(self.plotter)
+
+        # Creamos la figura 2D pero NO la agregamos al layout (no se muestra)
+        self.fig = plt.figure(figsize=(4, 4))
+        self.canvas = FigureCanvas(self.fig)  # necesario para que render_dump_to llame fig.canvas.draw()
+
+        # --- Layout raíz ---
+        root_l = QVBoxLayout(self)
+        root_l.addWidget(top)
+        root_l.addWidget(viewer, 1)
+
+        # Conexiones
+        self.btn_prev.clicked.connect(lambda: self._step(-1))
+        self.btn_next.clicked.connect(lambda: self._step(+1))
+        self.btn_load.clicked.connect(self._load_idx)
+
+        # Cargar primer índice disponible si existe
+        self._auto_seed_index()
+
+    # ----------- helpers -----------
+    def _pattern_path(self, i: int) -> str:
+        return self.pattern.format(i=i)
+
+    def _auto_seed_index(self):
+        for i in range(0, 10000):
+            if Path(self._pattern_path(i)).exists():
+                self.idx.setValue(i)
+                self._load_idx()
+                return
+        self.path_lbl.setText("(no encontrado)")
+
+    def _step(self, delta: int):
+        new_i = max(0, self.idx.value() + delta)
+        self.idx.setValue(new_i)
+        self._load_idx()
+
+    def _load_idx(self):
+        p = self._pattern_path(self.idx.value())
+        self.path_lbl.setText(p)
+        if not Path(p).exists():
+            QMessageBox.warning(self, "No existe", f"No se encontró:\n{p}")
+            return
+        try:
+            # Reutilizamos tu función de render (3D + 2D interno no visible)
+            render_dump_to(self.plotter, self.fig, p)
+        except Exception as e:
+            QMessageBox.critical(self, "Error", str(e))
 
 def main():
     app = QApplication(sys.argv)
